.. pydgrid
Python Distribution System Simulator



:Name: pydss
:Website: https://pydgrid.github.io/
:Author: Juan Manuel Mauricio |orcid|
:Version: 0.3.1

.. |orcid| image:: https://img.shields.io/badge/id-0000--0002--2187--161X-a6ce39.svg
   :target: http://orcid.org/0000-0002-5702-0198
